
DigitsWindow =  class( Turbine.UI.Window );

function DigitsWindow:Constructor()
	Turbine.UI.Window.Constructor( self );

	local WindowWidth = 100;
	local WindowHeight = 50;
	
	self:SetSize(WindowWidth,WindowHeight);
	self:SetMouseVisible(true);
	self:SetVisible(true);
	self.locked = true;
		
	self.DigitsLabel = Turbine.UI.Label();
	self.DigitsLabel:SetParent(self);
	self.DigitsLabel:SetPosition(5,5);
	self.DigitsLabel:SetMouseVisible(false);	
	
end

function DigitsWindow:LoadSettings(DefaultLeft, DefaultTop, DefaultAlpha, DefaultFormat, DefaultFont )
	self.settings = Turbine.PluginData.Load( Turbine.DataScope.Character, self.settingstable );

	if ( type( self.settings ) ~= "table" ) then
		self.settings = { };
	end
	
	if ( not self.settings.LeftPosition ) then
		self.settings.LeftPosition = DefaultLeft;
	end
	
	if ( not self.settings.TopPosition ) then
		self.settings.TopPosition = DefaultTop;
	end

	if ( not self.settings.AlphaChannel ) then
		self.settings.AlphaChannel = DefaultAlpha;
	end
	
	if ( not self.settings.TextFormat ) then
		self.settings.TextFormat = DefaultFormat;
	end
		
	if ( not self.settings.TextFont ) then
		self.settings.TextFont = DefaultFont;
	end
end


function DigitsWindow:SaveSettings()
	Turbine.PluginData.Save( Turbine.DataScope.Character, self.settingstable, self.settings );
end


function DigitsWindow:MouseDown( args )
	if ( args.Button == Turbine.UI.MouseButton.Left ) then
		if self.locked == false then
		self.dragStartX = args.X;
		self.dragStartY = args.Y;
		self.dragging = true;
		end
	end
	
	if ( args.Button == Turbine.UI.MouseButton.Right ) then
		local contextMenu = Turbine.UI.ContextMenu();
		local contextMenuItems = contextMenu:GetItems();

		local formatMenuItem = Turbine.UI.MenuItem( "Formats" );
		local lockMenuItem = Turbine.UI.MenuItem( "Toggle Lock" );
		lockMenuItem.Click  = function( sender, args )
			self:LockPosition();
		end

		local alphaMenuItem = Turbine.UI.MenuItem( "Toggle Alpha" );
		alphaMenuItem.Click  = function( sender, args )
			self:AlphaToggle();					
			self:SaveSettings();		
		end	
		
		local fontMenuItem = Turbine.UI.MenuItem( "Fonts" );
	
		local formatMenuItems = formatMenuItem:GetItems();
		

		local curMaxMenuItem = Turbine.UI.MenuItem( "Current | Max" );
		curMaxMenuItem.Click  = function( sender, args )
			self.textlayout = "Current | Max";
			self.settings.TextFormat = self.textlayout;
			self:SaveSettings();
			Updates();			
		end	
		
		local shortMenuItem = Turbine.UI.MenuItem( "Current Short" );
		shortMenuItem.Click  = function( sender, args )
			self.textlayout = "Current Short";
			self.settings.TextFormat = self.textlayout;
			self:SaveSettings();
			Updates();			
		end

		local longMenuItem = Turbine.UI.MenuItem( "Current Long" );
		longMenuItem.Click  = function( sender, args )
			self.textlayout = "Current Long";
			self.settings.TextFormat = self.textlayout;
			self:SaveSettings();
			Updates();
		end

		
		local percentMenuItem = Turbine.UI.MenuItem( "Percentage" );
		percentMenuItem.Click  = function( sender, args )
			self.textlayout = "Percentage";
			self.settings.TextFormat = self.textlayout;
			self:SaveSettings();
			Updates();
		end
		
		local fontMenuItems = fontMenuItem:GetItems();
		
		local fontAMenuItem = Turbine.UI.MenuItem( "TrajanPro18" );
		fontAMenuItem.Click = function( sender, args )
			self.textfont = Turbine.UI.Lotro.Font.TrajanPro18;
			self.settings.TextFont = self.textfont;
			self:SaveSettings();
			Updates();
		end

		local fontBMenuItem = Turbine.UI.MenuItem( "TrajanPro20" );
		fontBMenuItem.Click = function( sender, args )
			self.textfont = Turbine.UI.Lotro.Font.TrajanPro20;
			self.settings.TextFont = self.textfont;
			self:SaveSettings();
			Updates();
		end
		
		local fontCMenuItem = Turbine.UI.MenuItem( "TrajanPro23" );
		fontCMenuItem.Click = function( sender, args )
			self.textfont = Turbine.UI.Lotro.Font.TrajanPro23;
			self.settings.TextFont = self.textfont;
			self:SaveSettings();
			Updates();
		end
		
		local fontDMenuItem = Turbine.UI.MenuItem( "TrajanProBold25" );
		fontDMenuItem.Click = function( sender, args )
			self.textfont = Turbine.UI.Lotro.Font.TrajanProBold25;
			self.settings.TextFont = self.textfont;
			self:SaveSettings();
			Updates();
		end
		
		local fontEMenuItem = Turbine.UI.MenuItem( "TrajanProBold36" );
		fontEMenuItem.Click = function( sender, args )
			self.textfont = Turbine.UI.Lotro.Font.TrajanProBold36;
			self.settings.TextFont = self.textfont;
			self:SaveSettings();
			Updates();
		end
		
		fontMenuItems:Add( fontAMenuItem );
		fontMenuItems:Add( fontBMenuItem );
		fontMenuItems:Add( fontCMenuItem );
		fontMenuItems:Add( fontDMenuItem );
		fontMenuItems:Add( fontEMenuItem );

		formatMenuItems:Add( curMaxMenuItem );
		formatMenuItems:Add( shortMenuItem );
		formatMenuItems:Add( longMenuItem );
		formatMenuItems:Add( percentMenuItem );
		
		contextMenuItems:Add( formatMenuItem );
		contextMenuItems:Add( fontMenuItem );
		contextMenuItems:Add( lockMenuItem );
		contextMenuItems:Add( alphaMenuItem );
		contextMenu:ShowMenu();
	end
	
end

function DigitsWindow:MouseMove( args )
	local left, top = self:GetPosition();
	
	if ( self.dragging ) then
		self:SetPosition( left + ( args.X - self.dragStartX ), top + ( args.Y - self.dragStartY ) );
	end
end


function DigitsWindow:MouseUp( args )
	if ( args.Button == Turbine.UI.MouseButton.Left ) then
		self.dragging = false;
		local left, top = self:GetPosition();
		self.settings.LeftPosition = left;
		self.settings.TopPosition = top;
		self:SaveSettings();
	end
end

function DigitsWindow:LockPosition( )
		
	if ( self.locked ) then
		self.locked = false;
	else
		self.locked = true;
		
	end
end

function DigitsWindow:AlphaToggle( )		
	if ( self.settings.AlphaChannel == 1 ) then
		self:SetBackColor(Turbine.UI.Color(0.0, 0, 0, 0));
		self.settings.AlphaChannel =  0;	
	else
		self:SetBackColor(Turbine.UI.Color(0.75, 0, 0, 0));
		self.settings.AlphaChannel =  1;
	end
end

function DigitsWindow:TextFormat(current, max)
	local Icurrent = string.format("%i", current);
	local Imax = string.format("%i", max);
	local IcurrentShort = string.format("%.2f", (current/1000));
	local Ipercentage = string.format("%i", ((current/max) * 100));
	if self.textlayout == "Current | Max" then
		return (Icurrent .. " | " .. Imax);
	elseif self.textlayout == "Current Short" then
		return (IcurrentShort .. "k");

	elseif self.textlayout == "Current Long" then
		return (Icurrent);

	else 
		return (Ipercentage .."%");
	
	end
	

end
